@@ -48,7 +48,7 @@ class Register(BaseRegElement):
         self._callback_list = []
         
         
-    def _stringData(self):
+    def _stringData(self, lang=None):
         try:
             return '0x{3:04x}({3:d}) ; addr:{0:02X} ×{1:d} {2!s} '.format(
                     self.addr, 
@@ -132,7 +132,7 @@ class BitFieldRegister(Register):
         else:
             return self._bits[-1].addr + self._bits[-1].size
         
-    def _stringData(self):
+    def _stringData(self, lang=None):
         try:
             return super()._stringData() + " ; count:{}".format(len(self)) 
         except Exception as e:
@@ -149,7 +149,7 @@ class BitFieldRegister(Register):
         return self._index[name]
         
         
-    def toStringChildren(self, indent=1, prefix='', end='', depth=0):
+    def toStringChildren(self, indent=1, prefix='', end='', depth=0, lang=None):
         '''Returns a pretty listing of registers (children) of this group.
         
         :param indent: Indentation level (optional, default: 1)
@@ -171,7 +171,7 @@ class BitFieldRegister(Register):
             idx_fmt = '{0:02d} ‒ '
         else:
             idx_fmt = '{0:d} ‒ '
-        return prefix + '\n'.join( [x.toString(indent,idx_fmt.format(i),depth=depth-1) for (i,x) in enumerate(self._bits)]  ) + end      
+        return prefix + '\n'.join( [x.toString(indent,idx_fmt.format(i),depth=depth-1, lang=lang) for (i,x) in enumerate(self._bits)]  ) + end      
                    
 
     def add(self, *bits):
@@ -222,7 +222,7 @@ class RegisterArray(Register):
                 return True
         return False
     
-    def _stringData(self):
+    def _stringData(self, lang=None):
         try:
             s = '['+','.join( '0x{0:04x}({0:d})'.format(r.value) for r in self)+"]"
             return s + ' ; addr:{0:02X} ×{1:d} {2!s} '.format(
@@ -310,7 +310,7 @@ class RegBit(BaseRegElement):
     def __eq__(self, other):
         return self.name == other.name
     
-    def _stringData(self):
+    def _stringData(self, lang=None):
         return "{0:d}".format(self.get())
     
     def alter(self, value):
