@@ -4,19 +4,20 @@
 :date: 2021-02-24 Creation
 '''
 
-from .common import DBoardPreferedDapiMode
-from dapi2.dreg.register import Register, RegBit, DRegUndefinedError
-from dapi2.dapi2 import DApiAccessLevel
-import logging
-from dboard.workspace import WorkspacesContainer, StandbyWorkspace, Workspace,\
-    BaseWorkspace
-from dapi2.common import versionToWord, dateToWord, wordToDate, wordToVersion
-from dapi2.dreg.group import RegGroup
-from dboard.common import LastReset, ValueRange, DBoardException,\
-    SystemModeConfig
 import os
+import logging
+
+from dapi2.dreg.register import Register, RegBit, DRegUndefinedError
+from dapi2.dreg.group import RegGroup
+from dapi2.dapi2 import DApiAccessLevel
+from dapi2.common import versionToWord, dateToWord, wordToDate, wordToVersion
 from dapi2.dmsg.message import CommandMessage
 
+from .common import DBoardPreferedDapiMode, LastReset, ValueRange, DBoardException, SystemModeConfig
+from .workspace import WorkspacesContainer, StandbyWorkspace, Workspace, BaseWorkspace
+from .analoginput import PressureSensor, ElectricalSensor
+from dboard.analoginput import PowerSupply, ReferenceSensor
+
 
 
 class BaseDBoard(object):
@@ -63,6 +64,7 @@ class BaseDBoard(object):
         self.dmode = dmode
         self._workspace = None
         self._workspaces = WorkspacesContainer(self)
+        self._analog_inputs = {}
         self.speed_range = ValueRange(0,40000)
         self.torque_range = ValueRange(0,7000)
         self.powersupply_range = ValueRange(30,36)
@@ -235,10 +237,10 @@ class BaseDBoard(object):
         '''
         self.dapi.cmd.connect(level,passwd) 
         try:
-            self.dapi.regs.scsr.access.set(level)
+            self.dapi.regs.scsr.access.set(level.value)
         except DRegUndefinedError:
             self.dapi.readReg(self.dapi.regs.scsr)
-            self.dapi.regs.scsr.access.set(level)
+            self.dapi.regs.scsr.access.set(level.value)
         
         
     def setWorkspace(self, workspace):
@@ -444,7 +446,7 @@ class BaseDBoard(object):
     def setMotorSpeed(self, speed):
         '''Sets the motor speed
         
-        :param int speed: The new motor speed.
+        :param int speed: The new motor speed [rpm].
         '''
         self.setReg(self.dapi.regs.scr, speed)
         
@@ -490,6 +492,21 @@ class BaseDBoard(object):
             self.getRegisters('msr')
             return self.dapi.regs.msr.value
         
+    def setMotorCurrent(self, torque):
+        '''Sets the maximum motor current
+        
+        :param int torque: The new maximum motor current [mA].
+        '''
+        self.setReg(self.dapi.regs.scr, torque) 
+        
+    def motorCurrent(self):
+        '''Returns the maximum motor current set point'''
+        try:
+            return self.dapi.regs.ccr.valued
+        except DRegUndefinedError:
+            self.getRegisters('ccr')
+            return self.dapi.regs.ccr.value
+        
     def motorRealCurrent(self):
         '''Returns the real motor current'''
         try:
@@ -682,6 +699,13 @@ class BaseDBoard(object):
     @property
     def name(self):
         return self.getName().lower()
+    @property
+    def sn(self):
+        return self.regs.snr.value
+    @property
+    def analogInputs(self):
+        return self._analog_inputs.values()
+    
     
     
 class DBoard(BaseDBoard):
@@ -692,6 +716,18 @@ class DBoard(BaseDBoard):
     number = '00'
     '''Board type number'''
     
-    pass
+    
+    
+    def __init__(self, dapi, dmode=DBoardPreferedDapiMode.REGISTER):
+        BaseDBoard.__init__(self, dapi, dmode=dmode)
+        self._analog_inputs = dict( 
+                ((sensor.name, sensor) for sensor in (
+                    PressureSensor(self, 'pressure', self.regs.prcr, cal_state_index=1),
+                    ReferenceSensor(self, 'electric', self.regs.elcr),
+                    ElectricalSensor(self, 'analog_0', self.regs.an0r),
+                    ElectricalSensor(self, 'analog_1', self.regs.an1r), 
+                    PowerSupply(self, 'power', self.regs.psvr),)
+                    )
+            )
         
     
\ No newline at end of file
