@@ -108,7 +108,7 @@ class SystemModeConfig(IntFlag):
     @property
     def shortname(self):
         return self.get_descr(self, 2)
-
+    
 class LastReset(IntEnum):
     DAPI = 0
     POWERUP = 1
@@ -134,7 +134,13 @@ class LastReset(IntEnum):
     def help(self):
         return self.get_descr(self, 1)
     
-    
+class CalibrationProcessState(IntEnum):
+    ERROR = -3
+    WARNING = -2
+    ABORTED = -1
+    IDLE = 0
+    PENDING = 1
+    COMPLETED = 9
     
 
     
