@@ -4,8 +4,8 @@
 :date: 2021-02-24 Creation
 '''
 
-from .base import DBoard
-from dboard.base import DBoardPreferedDapiMode
+from .base import DBoard, DBoardPreferedDapiMode
+
 
 class Board30(DBoard):
     '''Class for MB-30 Dassym's board.'''
@@ -16,5 +16,7 @@ class Board30(DBoard):
     def __init__(self, dapi, dmode=DBoardPreferedDapiMode.REGISTER):
         '''Constructor'''
         super().__init__(dapi, dmode)
-        self.speed_range.set(1000,40000) 
-        
\ No newline at end of file
+        self.speed_range.set(1000,40000)
+        
+        
+            
\ No newline at end of file
